@@ -42,7 +42,7 @@ build_time_vars = {'ABIFLAGS': '',
                       '-Wl,-R/usr/X11R7/lib',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-ffi' "
-                "'--with-threads' '--without-ensurepip' '--without-pymalloc' "
+                "'--without-ensurepip' '--without-pymalloc' "
                 "'--prefix=/usr/pkg' '--build=armv6--netbsdelf-eabihf' "
                 "'--host=armv6--netbsdelf-eabihf' '--mandir=/usr/pkg/man' "
                 "'build_alias=armv6--netbsdelf-eabihf' "
@@ -56,8 +56,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/pkg/include',
  'CONFINCLUDEPY': '/usr/pkg/include/python3.7',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.2/coverage.info',
- 'COVERAGE_REPORT': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.2/lcov-report',
+ 'COVERAGE_INFO': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3/coverage.info',
+ 'COVERAGE_REPORT': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
@@ -134,6 +134,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
  'HAVE_CRYPT_H': 0,
+ 'HAVE_CRYPT_R': 0,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
  'HAVE_CURSES_FILTER': 1,
@@ -540,7 +541,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBRARY': 'libpython3.7.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lintl -lpthread  -lutil',
+ 'LIBS': '-lcrypt -lintl -lpthread  -lutil',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': 'gcc -pthread',
  'LINKFORSHARED': '-Wl,--export-dynamic',
@@ -682,12 +683,12 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.2',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lintl -lpthread  -lutil',
+ 'SHLIBS': '-lcrypt -lintl -lpthread  -lutil',
  'SHLIB_SUFFIX': '.so',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -724,10 +725,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.2 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.2 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -748,8 +749,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.2',
- 'abs_srcdir': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.2',
+ 'abs_builddir': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3',
+ 'abs_srcdir': '/mnt/earmv6hf/pkgsrc/lang/python37/work.earmv6hf/Python-3.7.3',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
